==> moodle-2.9.2.zip: moodle/blocks/tag_youtube/lang/en/block_tag_youtube.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_tag_youtube', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_tag_youtube
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['anycategory'] = 'Any category';
$string['apierror'] = 'The Youtube API key is not set. Contact your administrator.';
$string['apikey'] = 'API key';
$string['apikeyinfo'] = 'Get a <a href="https://developers.google.com/youtube/v3/getting-started">Google API key</a> for your Moodle site.';
$string['autosvehicles'] = 'Autos &amp; Vehicles';
$string['category'] = 'Category';
$string['comedy'] = 'Comedy';
$string['configtitle'] = 'Title';
$string['education'] = 'Education';
$string['entertainment'] = 'Entertainment';
$string['filmsanimation'] = 'Films &amp; Animation';
$string['gadgetsgames'] = 'Gadgets &amp; Games';
$string['howtodiy'] = 'How-to &amp; DIY';
$string['includeonlyvideosfromplaylist'] = 'Include only videos from the playlist with id';
$string['music'] = 'Music';
$string['newspolitics'] = 'News &amp; Politics';
$string['numberofvideos'] = 'Number of videos';
$string['peopleblogs'] = 'People &amp; Blogs';
$string['petsanimals'] = 'Pets &amp; Animals';
$string['pluginname'] = 'YouTube';
$string['requesterror'] = 'Data could not be obtained from the server. Contact your administrator if the problem persist.';
$string['scienceandtech'] = 'Science &amp; Tech';
$string['sports'] = 'Sports';
$string['tag_youtube:addinstance'] = 'Add a new YouTube block';
$string['travel'] = 'Travel &amp; Places';

==> moodle-3.4.6.zip: moodle/blocks/tag_youtube/lang/en/block_tag_youtube.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_tag_youtube', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_tag_youtube
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['anycategory'] = 'Any category';
$string['apierror'] = 'The YouTube API key is not set. Contact your administrator.';
$string['apikey'] = 'API key';
$string['apikeyinfo'] = 'Get a <a href="https://developers.google.com/youtube/v3/getting-started">Google API key</a> for your Moodle site.';
$string['autosvehicles'] = 'Autos & Vehicles';
$string['category'] = 'Category';
$string['comedy'] = 'Comedy';
$string['configtitle'] = 'Title';
$string['education'] = 'Education';
$string['entertainment'] = 'Entertainment';
$string['filmsanimation'] = 'Films & Animation';
$string['gadgetsgames'] = 'Gadgets & Games';
$string['howtodiy'] = 'How-to & DIY';
$string['includeonlyvideosfromplaylist'] = 'Include only videos from the playlist with id';
$string['music'] = 'Music';
$string['newspolitics'] = 'News & Politics';
$string['numberofvideos'] = 'Number of videos';
$string['peopleblogs'] = 'People & Blogs';
$string['petsanimals'] = 'Pets & Animals';
$string['pluginname'] = 'YouTube';
$string['requesterror'] = 'Data could not be obtained from the server. Contact your administrator if the problem persists.';
$string['scienceandtech'] = 'Science & Tech';
$string['sports'] = 'Sports';
$string['tag_youtube:addinstance'] = 'Add a new YouTube block';
$string['travel'] = 'Travel & Places';
$string['privacy:metadata'] = 'The YouTube block only shows data stored in other locations.';
